summaryrefslogtreecommitdiff
path: root/gold/workqueue.h
diff options
context:
space:
mode:
authorIan Lance Taylor <iant@google.com>2008-02-28 19:46:06 +0000
committerIan Lance Taylor <iant@google.com>2008-02-28 19:46:06 +0000
commitda769d5629564b82d4eec1b256ffc562d5c01624 (patch)
treec575a166927823074cd07dad6347b0e90072340f /gold/workqueue.h
parenta7dfd0102bbf259cad78b322915523adb366837a (diff)
downloadbinutils-gdb-da769d5629564b82d4eec1b256ffc562d5c01624.tar.gz
Read input scripts which look like input objects with proper
serialization.
Diffstat (limited to 'gold/workqueue.h')
-rw-r--r--gold/workqueue.h14
1 files changed, 10 insertions, 4 deletions
diff --git a/gold/workqueue.h b/gold/workqueue.h
index 5f2137e46ac..7c87d15adb3 100644
--- a/gold/workqueue.h
+++ b/gold/workqueue.h
@@ -205,10 +205,16 @@ class Workqueue
void
queue(Task*);
// Add a new task to the front of the work queue. It will be the
// next task to run if it is ready.
void
- queue_front(Task*);
+ queue_soon(Task*);
+
+ // Add a new task to the work queue which should run next if it is
+ // ready.
+ void
+ queue_next(Task*);
// Process all the tasks on the work queue. This function runs
// until all tasks have completed. The argument is the thread
@@ -228,7 +234,7 @@ class Workqueue
// Add a task to a queue.
void
- add_to_queue(Task_list* queue, Task* t);
+ add_to_queue(Task_list* queue, Task* t, bool front);
// Find a runnable task, or wait for one.
Task*
@@ -205,10 +205,16 @@ class Workqueue
void
queue(Task*);
- // Add a new task to the front of the work queue. It will be the
- // next task to run if it is ready.
+ // Add a new task to the work queue which should run soon. If the
+ // task is ready, it will be run before any tasks added using
+ // queue().
void